/* MColorPopup.cpp - color popup for liblayout; displays a colored area, single click
 *                   brings up a window with a BColorControl; drag&drop is supported.
 *
 * Copyright (c) 2004 by Christian Packmann.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef _MCOLORPOPUP_H_
#define _MCOLORPOPUP_H_

#include "layout.h"
#include "MDividable.h"
#include <Invoker.h>
#include <Window.h>
#include <View.h>
#include <Rect.h>
#include <ColorControl.h>

#include <stdio.h>

#define MSG_SET_COLOR			'!scl'
#define MSG_COLORWINDOW_CLOSE	'!cwc'

class ColorWindow : public BWindow {
public:
	BColorControl* mColCtrl;
	BHandler *mTarget;
	ColorWindow(BPoint where, alignment align, rgb_color color, BHandler* target, const char* title=NULL);
	bool QuitRequested(void);
	void MessageReceived(BMessage*);
};

class MColorPopup : public MView, public BControl {
private:
	// general storage
	rgb_color	mColor;
	ColorWindow* mColorWindow;
	const char* mLabel;
	const char* mWindowTitle;
	const BHandler *mTarget;
	// drag'n'drop
	BRect mHitArea;
	BPoint mDragStartPoint;
	bool mIsDragging;
	// drawing-related stuff
	float mLabelWidth;
	float mDivideSameAs;
	font_height mFontHeight;
	static const int kColorfieldXMin = 12;
	static const int kColorfieldYMin = 10;
	static const int kLabelSpacing = 4;
	static const int kOuterXSpacing = 2;
	static const int kOuterYSpacing = 2;
	void DrawRaisedFrame(BRect frame);
	void UpdateInternalState();
public:
	MColorPopup(const char* label, rgb_color color, BMessage* msg=NULL,
			BHandler* target=NULL, const char* winTitle=NULL);
	~MColorPopup();
	virtual void Draw(BRect updateRect);
	virtual void AttachedToWindow();
	virtual void MouseDown(BPoint where);
	virtual void MouseMoved(BPoint, uint32, const BMessage*);
	virtual void MouseUp(BPoint);
	virtual void KeyDown(const char*, int32);
	virtual void MessageReceived(BMessage *msg);
	virtual minimax layoutprefs(void);
	virtual BRect layout(BRect size);
	virtual void DivideSameAs(MDividable *);
	virtual float LabelWidth();
	rgb_color Color();
	uint8 Red();
	uint8 Green();
	uint8 Blue();
	void SetColor(rgb_color col);
	void SetRed(uint8 r);
	void SetGreen(uint8 g);
	void SetBlue(uint8 b);
};

#endif
