/* WindowShadeGUI.h - some definitions for WindowShadeGUI
 *
 * Copyright (c) 2004 by Christian Packmann.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */
#ifndef _WINDOWSHADEGUI_H_
#define _WINDOWSHADEGUI_H_

#include "MColorPopup.h"

#define MSG_ACTIVE_TAB 		'col0'
#define MSG_ACTIVE_TITLE 	'col1'
#define MSG_ACTIVE_BORDER 	'col2'
#define MSG_INACTIVE_TITLE 	'col3'
#define MSG_INACTIVE_BORDER 'col4'
#define MSG_FRAME 			'col5'
#define MSG_LOAD			'load'
#define MSG_SAVE			'save'
#define MSG_REVERT			'revt'
#define MSG_DEFAULTS		'dflt'
#define MSG_APPLY			'aply'

#define PREFS_ACTIVE_TAB		"ActiveTabColor"
#define PREFS_ACTIVE_TITLE		"ActiveTitleColor"
#define PREFS_ACTIVE_BORDER		"ActiveBorderColor"
#define PREFS_INACTIVE_TITLE	"InactiveTitleColor"
#define PREFS_INACTIVE_BORDER 	"InactiveBorderColor"
#define PREFS_FRAME				"FrameColor"

#define PREFS_FILE_NAME	"WindowShadeGUI_Settings"

class WSGUIPrefs {
public:
	rgb_color mRGBActiveTab;
	rgb_color mRGBActiveTitle;
	rgb_color mRGBActiveBorder;
	rgb_color mRGBInactiveTitle;
	rgb_color mRGBInactiveBorder;
	rgb_color mRGBFrame;
	BRect mWindowFrame;
	void SetToDefaults(void);
	void Load(const entry_ref *, bool loadAll=true);
	void Save(const entry_ref *, bool saveAll=true);
};
void WSGUIPrefs::SetToDefaults(void) {
	// BeOS default colors
	mRGBActiveTab.red   = 0xff;
	mRGBActiveTab.green = 0xcb;
	mRGBActiveTab.blue  = 0x00;
	mRGBActiveTitle.red   = 0x00;
	mRGBActiveTitle.green = 0x00;
	mRGBActiveTitle.blue  = 0x00;
	mRGBActiveBorder.red   = 0xd8;
	mRGBActiveBorder.green = 0xd8;
	mRGBActiveBorder.blue  = 0xd8;
	mRGBInactiveTitle.red   = 0x80;
	mRGBInactiveTitle.green = 0x80;
	mRGBInactiveTitle.blue  = 0x80;
	mRGBInactiveBorder.red   = 0xeb;
	mRGBInactiveBorder.green = 0xeb;
	mRGBInactiveBorder.blue  = 0xeb;
	mRGBFrame.red   = 0x98;
	mRGBFrame.green = 0x98;
	mRGBFrame.blue  = 0x98;
}


class WSGUIWindow : public MWindow {
private:
	MColorPopup* mCPActiveTab;
	MColorPopup* mCPActiveTitle;
	MColorPopup* mCPActiveBorder;
	MColorPopup* mCPInactiveTitle;
	MColorPopup* mCPInactiveBorder;
	MColorPopup* mCPFrame;
	MButton* mBTLoad;
	MButton* mBTSave;
	MButton* mBTRevert;
	MButton* mBTDefaults;
	MButton* mBTApply;
	BFilePanel* mLoadPanel;
	BFilePanel* mSavePanel;
	void Apply();
	void Revert();
public:
	void CallWindowShade(void);
	void UpdateColorsFromPrefs(void);
	WSGUIWindow(BRect frame);
	~WSGUIWindow();
	virtual void MessageReceived(BMessage *);
	virtual bool QuitRequested();
};


class WSGUIApp : public MApplication {
public:
	WSGUIApp();
	~WSGUIApp();
	void LoadPrefs();
	void SavePrefs();
	void ErrorAlert(const char*);
	virtual void MessageReceived(BMessage* msg);
	virtual void RefsReceived(BMessage* msg);
	WSGUIPrefs mPrefs;
	WSGUIPrefs mPrefsCopy;
	WSGUIWindow* mWSGUIWindow;
};


#endif
